@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
   code based on calligra autocorrection.
 
   This program is free software; you can redistribute it and/or modify it
@@ -482,17 +482,21 @@ void AutoCorrection::addNonBreakingSpace()
             }
         } else {
             //°C (degres)
-            const QChar previousChar = text.at(mCursor.position() - 2 - block.position());
-            if (lastChar == QLatin1Char('C') && previousChar == QChar(0x000B0)) {
-                const int pos = mCursor.position() - 3 - block.position();
-                if (pos >= 0) {
-                    const QChar previousChar = text.at(pos);
-                    if (previousChar.isSpace()) {
-                        QTextCursor cursor(mCursor);
-                        cursor.setPosition(pos);
-                        cursor.setPosition(pos + 1, QTextCursor::KeepAnchor);
-                        cursor.deleteChar();
-                        mCursor.insertText(mNonBreakingSpace);
+            const int pos = mCursor.position() - 2 - block.position();
+            if (pos >= 0) {
+                const QChar previousChar = text.at(pos);
+
+                if (lastChar == QLatin1Char('C') && previousChar == QChar(0x000B0)) {
+                    const int pos = mCursor.position() - 3 - block.position();
+                    if (pos >= 0) {
+                        const QChar previousChar = text.at(pos);
+                        if (previousChar.isSpace()) {
+                            QTextCursor cursor(mCursor);
+                            cursor.setPosition(pos);
+                            cursor.setPosition(pos + 1, QTextCursor::KeepAnchor);
+                            cursor.deleteChar();
+                            mCursor.insertText(mNonBreakingSpace);
+                        }
                     }
                 }
             }
@@ -906,7 +910,7 @@ int AutoCorrection::advancedAutocorrect()
             continue;
         }
         if (actualWord.endsWith(i.key())
-            || actualWord.toLower().endsWith(i.key())
+            || actualWord.endsWith(i.key(), Qt::CaseInsensitive)
             || actualWordWithFirstUpperCase.endsWith(i.key())) {
             int pos = mWord.lastIndexOf(i.key());
             if (pos == -1) {
@@ -915,6 +919,9 @@ int AutoCorrection::advancedAutocorrect()
             if (pos == -1) {
                 pos = actualWordWithFirstUpperCase.lastIndexOf(i.key());
             }
+            if (pos == -1) {
+                continue;
+            }
             QString replacement = i.value();
 
             // Keep capitalized words capitalized.
