@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,10 +19,14 @@
 #ifndef AutoCorrectionLanguage_H
 #define AutoCorrectionLanguage_H
 
-#include <KComboBox>
+#include <QComboBox>
 #include "pimcommon_export.h"
 
 namespace PimCommon {
+/**
+ * @brief The AutoCorrectionLanguage class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT AutoCorrectionLanguage : public QComboBox
 {
 public:
@@ -32,7 +37,7 @@ public:
     * @brief language
     * @return specified language
     */
-    QString language() const;
+    Q_REQUIRED_RESULT QString language() const;
 
     /**
      * @brief setLanguage
