@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ public:
     virtual void doResetToDefaultsOther();
     virtual void defaults();
     virtual void initialize();
+    void initializeDone();
 Q_SIGNALS:
     void descriptionChanged(const QString &description);
     void changed();
@@ -71,14 +72,14 @@ protected:
         bool mEnableFromUserSettings;
     };
     void savePlugins(const QString &groupName, const QString &prefixSettingKey, const QVector<PluginItem *> &listItems);
-    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList,
-                      const QString &configureGroupName = QString(), bool checkable = true);
+    void fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey, QVector<PluginItem *> &itemsList, const QString &configureGroupName = QString(), bool checkable = true);
     void resetToUserSettings(const QVector<PluginItem *> &items);
     void changeState(const QVector<PluginItem *> &items);
 
     QTreeWidget *mListWidget = nullptr;
 private:
     void slotConfigureClicked(QAction *act);
+    bool mInitializeDone = false;
 };
 }
 
