@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,6 +26,8 @@ public:
     CustomToolsPluginPrivate()
     {
     }
+
+    bool enabled = false;
 };
 
 CustomToolsPlugin::CustomToolsPlugin(QObject *parent)
@@ -37,3 +40,28 @@ CustomToolsPlugin::~CustomToolsPlugin()
 {
     delete d;
 }
+
+bool CustomToolsPlugin::hasConfigureDialog() const
+{
+    return false;
+}
+
+void CustomToolsPlugin::showConfigureDialog(QWidget *parent)
+{
+    Q_UNUSED(parent);
+}
+
+QString CustomToolsPlugin::description() const
+{
+    return {};
+}
+
+void CustomToolsPlugin::setIsEnabled(bool enabled)
+{
+    d->enabled = enabled;
+}
+
+bool CustomToolsPlugin::isEnabled() const
+{
+    return d->enabled;
+}
