@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +21,7 @@
 
 #include <QDialog>
 
-class KLineEdit;
+class QLineEdit;
 namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
@@ -33,17 +34,17 @@ public:
     ~TemplateEditDialog();
 
     void setTemplateName(const QString &name);
-    QString templateName() const;
+    Q_REQUIRED_RESULT QString templateName() const;
 
     void setScript(const QString &);
-    QString script() const;
+    Q_REQUIRED_RESULT QString script() const;
 
 private:
     void slotTemplateChanged();
     void readConfig();
     void writeConfig();
     KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
-    KLineEdit *mTemplateNameEdit = nullptr;
+    QLineEdit *mTemplateNameEdit = nullptr;
     QPushButton *mOkButton = nullptr;
 };
 }
