@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -104,14 +104,14 @@ void TemplateManager::loadTemplates(bool init)
 TemplateInfo TemplateManager::loadTemplate(const QString &themePath, const QString &defaultDesktopFileName)
 {
     TemplateInfo info;
-    const QString themeInfoFile = themePath + QDir::separator() + defaultDesktopFileName;
+    const QString themeInfoFile = themePath + QLatin1Char('/') + defaultDesktopFileName;
     KConfig config(themeInfoFile);
     KConfigGroup group(&config, QStringLiteral("Desktop Entry"));
 
     info.name = group.readEntry("Name", QString());
     const QString filename = group.readEntry("FileName", QString());
     if (!filename.isEmpty()) {
-        QFile file(themePath + QDir::separator() + filename);
+        QFile file(themePath + QLatin1Char('/') + filename);
         if (file.exists()) {
             if (file.open(QIODevice::ReadOnly)) {
                 info.script = QString::fromUtf8(file.readAll());
