@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,11 +17,11 @@
 
 #include "translatortest.h"
 #include "translator/translatorwidget.h"
-#include "kpimtextedit/plaintexteditorwidget.h"
+#include <KPIMTextEdit/PlainTextEditorWidget>
 
 #include <QPushButton>
 
-#include <qtest.h>
+#include <QTest>
 #include <qtestkeyboard.h>
 #include <qtestmouse.h>
 #include <QComboBox>
@@ -92,7 +92,6 @@ void TranslatorTest::shouldInvertLanguageWhenClickOnInvertButton()
     from->setCurrentIndex(fromIndex);
     to->setCurrentIndex(toIndex);
     QPushButton *invert = edit.findChild<QPushButton *>(QStringLiteral("invert-button"));
-    QCOMPARE(fromIndex != toIndex, true);
     QTest::mouseClick(invert, Qt::LeftButton);
     const int newFromIndex = from->currentIndex();
     const int newToIndex = to->currentIndex();
