@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -75,9 +75,10 @@ public:
     QPushButton *mModifyButton = nullptr;
     QPushButton *mUpButton = nullptr;
     QPushButton *mDownButton = nullptr;
+    QPushButton *mCustomButton = nullptr;
     QVBoxLayout *mButtonLayout = nullptr;
-    QString mAddDialogLabel;
-    QString mRemoveDialogLabel;
+    QString mAddDialogLabel = i18n("New entry:");
+    QString mRemoveDialogLabel = i18n("Do you want to remove selected text?");
 };
 
 SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode buttons, const QString &addLabel, const QString &removeLabel, const QString &modifyLabel, const QString &addDialogLabel)
@@ -167,6 +168,14 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
         connect(d->mDownButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotDown);
     }
 
+    if (buttons & Custom) {
+        d->mCustomButton = new QPushButton(i18n("&Customize..."), this);
+        d->mCustomButton->setAutoDefault(false);
+        d->mCustomButton->setEnabled(false);   // no selection yet
+        d->mButtonLayout->addWidget(d->mCustomButton);
+        connect(d->mCustomButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotCustomize);
+    }
+
     d->mButtonLayout->addStretch(1);   // spacer
 
     connect(d->mListBox, &QListWidget::currentItemChanged, this, &SimpleStringListEditor::slotSelectionChanged);
@@ -242,6 +251,12 @@ void SimpleStringListEditor::setButtonText(ButtonCode button, const QString &tex
         }
         d->mModifyButton->setText(text);
         return;
+    case Custom:
+        if (!d->mCustomButton) {
+            break;
+        }
+        d->mCustomButton->setText(text);
+        return;
     case Up:
     case Down:
         qCDebug(PIMCOMMON_LOG) << "SimpleStringListEditor: Cannot change text of"
@@ -287,6 +302,25 @@ void SimpleStringListEditor::slotAdd()
     addNewEntry();
 }
 
+void SimpleStringListEditor::slotCustomize()
+{
+    QListWidgetItem *item = d->mListBox->currentItem();
+    if (!item) {
+        return;
+    }
+    const QString newText = customEntry(item->text());
+    if (!newText.isEmpty()) {
+        item->setText(newText);
+        Q_EMIT changed();
+    }
+}
+
+QString SimpleStringListEditor::customEntry(const QString &text)
+{
+    Q_UNUSED(text);
+    return {};
+}
+
 void SimpleStringListEditor::slotRemove()
 {
     const QList<QListWidgetItem *> selectedItems = d->mListBox->selectedItems();
@@ -332,12 +366,12 @@ void SimpleStringListEditor::slotModify()
 
 void SimpleStringListEditor::setRemoveDialogLabel(const QString &removeDialogLabel)
 {
-    d->mRemoveDialogLabel = removeDialogLabel.isEmpty() ? i18n("Do you want to remove selected text?") : removeDialogLabel;
+    d->mRemoveDialogLabel = removeDialogLabel;
 }
 
 void SimpleStringListEditor::setAddDialogLabel(const QString &addDialogLabel)
 {
-    d->mAddDialogLabel = addDialogLabel.isEmpty() ? i18n("New entry:") : addDialogLabel;
+    d->mAddDialogLabel = addDialogLabel;
 }
 
 void SimpleStringListEditor::slotUp()
@@ -425,6 +459,10 @@ void SimpleStringListEditor::slotSelectionChanged()
     const bool theLast = (currentIndex >= d->mListBox->count() - 1);
     const bool theFirst = (currentIndex == 0);
 
+    if (d->mCustomButton) {
+        d->mCustomButton->setEnabled(uniqItemSelected);
+    }
+
     if (d->mUpButton) {
         d->mUpButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theFirst)
                                                      || (!uniqItemSelected)) && !allItemSelected);
