@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -41,7 +41,6 @@
 #include "pimcommon_export.h"
 
 class QListWidget;
-class QListWidgetItem;
 
 //
 //
@@ -59,19 +58,19 @@ class PIMCOMMON_EXPORT SimpleStringListEditor : public QWidget
     Q_OBJECT
 public:
     enum ButtonCode {
-        None = 0x00,
-        Add = 0x01,
-        Remove = 0x02,
-        Modify = 0x04,
-        Up = 0x08,
-        Down = 0x10,
+        None = 0,
+        Add = 1,
+        Remove = 2,
+        Modify = 4,
+        Up = 8,
+        Down = 16,
+        Custom = 32,
         All = Add | Remove | Modify | Up | Down,
         Unsorted = Add | Remove | Modify
     };
 
     /** Constructor. Populates the list with @p strings. */
-    explicit SimpleStringListEditor(QWidget *parent = nullptr, ButtonCode buttons = Unsorted, const QString &addLabel = QString(),
-                                    const QString &removeLabel = QString(), const QString &modifyLabel = QString(), const QString &addDialogLabel = QString());
+    explicit SimpleStringListEditor(QWidget *parent = nullptr, ButtonCode buttons = Unsorted, const QString &addLabel = QString(), const QString &removeLabel = QString(), const QString &modifyLabel = QString(), const QString &addDialogLabel = QString());
 
     ~SimpleStringListEditor() override;
     /** Sets the list of strings displayed to @p strings */
@@ -90,6 +89,8 @@ public:
     Q_REQUIRED_RESULT QSize sizeHint() const override;
 
     virtual void addNewEntry();
+    virtual QString customEntry(const QString &text);
+
     Q_REQUIRED_RESULT virtual QString modifyEntry(const QString &text);
     void setAddDialogLabel(const QString &addDialogLabel);
 
@@ -110,6 +111,7 @@ protected Q_SLOTS:
     void slotModify();
     void slotUp();
     void slotDown();
+    void slotCustomize();
 
     void slotSelectionChanged();
 
