@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -25,6 +25,10 @@
 #include "pimcommonakonadi_export.h"
 namespace PimCommon {
 class ContentTypeWidgetPrivate;
+/**
+ * @brief The ContentTypeWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMONAKONADI_EXPORT ContentTypeWidget : public QWidget
 {
     Q_OBJECT
@@ -32,11 +36,11 @@ public:
     explicit ContentTypeWidget(QWidget *parent = nullptr);
     ~ContentTypeWidget();
 
-    int currentIndex() const;
+    Q_REQUIRED_RESULT int currentIndex() const;
     void setCurrentIndex(int index);
 
     void setCurrentItem(const QString &name);
-    QString currentText() const;
+    Q_REQUIRED_RESULT QString currentText() const;
 
 Q_SIGNALS:
     void activated(int index);
