@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -26,6 +26,10 @@
 
 namespace PimCommon {
 class IncidencesForWidgetPrivate;
+/**
+ * @brief The IncidencesForWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMONAKONADI_EXPORT IncidencesForWidget : public QWidget
 {
     Q_OBJECT
@@ -33,7 +37,7 @@ public:
     explicit IncidencesForWidget(QWidget *parent = nullptr);
     ~IncidencesForWidget();
 
-    int currentIndex() const;
+    Q_REQUIRED_RESULT int currentIndex() const;
     void setCurrentIndex(int index);
 
 Q_SIGNALS:
