@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -17,12 +17,10 @@
 */
 
 #include "checkedcollectionwidget.h"
-#include <RecursiveCollectionFilterProxyModel>
 #include <CollectionFilterProxyModel>
 
 #include <Monitor>
 #include <EntityTreeModel>
-#include <EntityRightsFilterModel>
 #include <QSortFilterProxyModel>
 
 #include <KCheckableProxyModel>
@@ -38,11 +36,6 @@ class PimCommon::CheckedCollectionWidgetPrivate
 {
 public:
     CheckedCollectionWidgetPrivate()
-        : mFolderView(nullptr)
-        , mSelectionModel(nullptr)
-        , mCheckProxy(nullptr)
-        , mCollectionFilter(nullptr)
-        , mEntityTreeModel(nullptr)
     {
     }
 
@@ -76,7 +69,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
 
     Akonadi::CollectionFilterProxyModel *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
     mimeTypeProxy->setExcludeVirtualCollections(true);
-    mimeTypeProxy->addMimeTypeFilters(QStringList() << mimetype);
+    mimeTypeProxy->addMimeTypeFilters({mimetype});
     mimeTypeProxy->setSourceModel(d->mEntityTreeModel);
 
     // Create the Check proxy model.
