@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -40,11 +40,11 @@ public:
     ~PluginInterface();
 
     void setParentWidget(QWidget *widget);
-    QHash<PimCommon::ActionType::Type, QList<QAction *> > actionsType();
+    Q_REQUIRED_RESULT QHash<PimCommon::ActionType::Type, QList<QAction *> > actionsType();
     void createPluginInterface();
 
     void setPluginName(const QString &name);
-    void setServiceTypeName(const QString &name);
+    void setPluginDirectory(const QString &name);
     void initializePlugins();
     virtual void initializeInterfaceRequires(AbstractGenericPluginInterface *interface);
     static QString actionXmlExtension(PimCommon::ActionType::Type type);
